OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactes",
    "Name" : "Nom",
    "Organization" : "Societat",
    "Title" : "Títol",
    "All contacts" : "Totes los contactes",
    "Postal code" : "Còde postal",
    "City" : "Vila",
    "State or province" : "Estat o region",
    "Country" : "País",
    "Address" : "Adreça",
    "(new group)" : "(grop novèl)",
    "Last name" : "Nom",
    "First name" : "Prenom",
    "Additional names" : "Noms suplementaris",
    "New contact" : "Contacte novèl",
    "Not grouped" : "Pas gropats",
    "Nickname" : "Escais",
    "Notes" : "Nòtas",
    "Website" : "Site web",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Domicili",
    "Work" : "Professional(a)",
    "Other" : "Autre",
    "Groups" : "Gropes",
    "Birthday" : "Anniversari",
    "Email" : "Adreça corrièl",
    "Instant messaging" : "Messatjariá instantanèa",
    "Phone" : "Telefòn",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Pager" : "Messatgièr",
    "Voice" : "Votz",
    "Settings" : "Paramètres"
},
"nplurals=2; plural=(n > 1);");
